==> realestate-supervise-common-1.1.0-20240711.021433-51-sources.jar: cn/gtmap/realestate/supervise/entity/BaJzd.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 界址点信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_jzd")
public class BaJzd implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private int bsm;

    @XmlAttribute
    private String zdzhdm;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String jzdh;

    @XmlAttribute
    @Nullable
    private int sxh;

    @XmlAttribute
    private String jblx;

    @XmlAttribute
    private String jzdlx;

    @XmlAttribute
    @Nullable
    private String xzbz;

    @XmlAttribute
    @Nullable
    private String yzbz;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    private String qxdm;

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public int getBsm() {
        return bsm;
    }

    public void setBsm(int bsm) {
        this.bsm = bsm;
    }

    public String getZdzhdm() {
        return zdzhdm;
    }

    public void setZdzhdm(String zdzhdm) {
        this.zdzhdm = zdzhdm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getJzdh() {
        return jzdh;
    }

    public void setJzdh(String jzdh) {
        this.jzdh = jzdh;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getJblx() {
        return jblx;
    }

    public void setJblx(String jblx) {
        this.jblx = jblx;
    }

    public String getJzdlx() {
        return jzdlx;
    }

    public void setJzdlx(String jzdlx) {
        this.jzdlx = jzdlx;
    }

    public String getXzbz() {
        return xzbz;
    }

    public void setXzbz(String xzbz) {
        this.xzbz = xzbz;
    }

    public String getYzbz() {
        return yzbz;
    }

    public void setYzbz(String yzbz) {
        this.yzbz = yzbz;
    }
}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/entity/BaJzd.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.jgbsm;
import cn.gtmap.realestate.supervise.core.reflect.id;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 界址点信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_jzd")
public class BaJzd implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private int bsm;

    @XmlAttribute
    private String zdzhdm;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String jzdh;

    @XmlAttribute
    @Nullable
    private int sxh;

    @XmlAttribute
    private String jblx;

    @XmlAttribute
    private String jzdlx;

    @XmlAttribute
    @Nullable
    private String xzbz;

    @XmlAttribute
    @Nullable
    private String yzbz;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    private String qxdm;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 界址点位说明 */
    @XmlAttribute
    private String jzdwsm;

    /** 界址说明表 */
    @XmlAttribute
    private String jzsmb;

    /** 中央子午线经度 */
    @XmlAttribute
    private String zyzwxjd;

    /** 原宗地/宗海代码 */
    @XmlAttribute
    private String yzdzhdm;

    /** 备注 */
    @XmlAttribute
    private String bz;

    /** 监管标识码 */
    @jgbsm
    private String jgbsf;

    /** 登记状态 */
    @XmlAttribute
    private String djzt;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public int getBsm() {
        return bsm;
    }

    public void setBsm(int bsm) {
        this.bsm = bsm;
    }

    public String getZdzhdm() {
        return zdzhdm;
    }

    public void setZdzhdm(String zdzhdm) {
        this.zdzhdm = zdzhdm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getJzdh() {
        return jzdh;
    }

    public void setJzdh(String jzdh) {
        this.jzdh = jzdh;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getJblx() {
        return jblx;
    }

    public void setJblx(String jblx) {
        this.jblx = jblx;
    }

    public String getJzdlx() {
        return jzdlx;
    }

    public void setJzdlx(String jzdlx) {
        this.jzdlx = jzdlx;
    }

    public String getXzbz() {
        return xzbz;
    }

    public void setXzbz(String xzbz) {
        this.xzbz = xzbz;
    }

    public String getYzbz() {
        return yzbz;
    }

    public void setYzbz(String yzbz) {
        this.yzbz = yzbz;
    }

    public String getJzdwsm() {
        return jzdwsm;
    }

    public void setJzdwsm(String jzdwsm) {
        this.jzdwsm = jzdwsm;
    }

    public String getJzsmb() {
        return jzsmb;
    }

    public void setJzsmb(String jzsmb) {
        this.jzsmb = jzsmb;
    }

    public String getZyzwxjd() {
        return zyzwxjd;
    }

    public void setZyzwxjd(String zyzwxjd) {
        this.zyzwxjd = zyzwxjd;
    }

    public String getYzdzhdm() {
        return yzdzhdm;
    }

    public void setYzdzhdm(String yzdzhdm) {
        this.yzdzhdm = yzdzhdm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJgbsf() {
        return jgbsf;
    }

    public void setJgbsf(String jgbsf) {
        this.jgbsf = jgbsf;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }
}
